@@ -48,4 +48,4 @@
       (set! alias (assoc-set! alias (car args-list) (cdr args-list)))
       (begin
 	(display "?alias: wrong number of arguments\n")
-	(display "usage: ?alias BUDDY BUDDY-LIST"))))
+	(display "usage: ?alias BUDDY BUDDY-LIST\n"))))
