@@ -102,7 +102,7 @@ install_new_hooks (void)
   /* hook: fh-message-send-hook
 
      is called from
-     file: yahoo-wrapper.c
+     file: yahoo-adapter.c
      function: send_message (...)
 
      with arguments
@@ -116,7 +116,7 @@ install_new_hooks (void)
     scm_create_hook ("fh-message-receive-hook", 2);
   /* hook: fh-message-receive-offline-hook
      is called from
-     file: yafh-wrapper.c
+     file: yafh-adapter.c
      function: send_message (...)
      with arguments
      "message-from" and "message-data"
@@ -136,7 +136,7 @@ install_new_hooks (void)
   /* hook: fh-message-receive-offline-hook
 
      is called from
-     file: yahoo-wrapper.c
+     file: yahoo-adapter.c
      function: process_offline_message (...)
      with arguments
      "message-from" "message-data" "message-time"
