@@ -15,6 +15,7 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */
 
+
 #include <stdio.h>
 #include <unistd.h>
 #include <fcntl.h>
@@ -29,14 +30,12 @@
 #include <config.h>
 #include <glib.h>
 
-#include "messenger.h"
 #include "extension.h"
 #include "fh-utils.h"
-#include "yahoo-wrapper.h"
+#include "yahoo-backend.h"
 #include "interpreter.h"
 #include "freehoo.h"
 
-
 /* private members REALLY. extern'ing these variables are strongly
    discouraged. instead use exported methods to access these variables
 */
@@ -47,6 +46,7 @@ char *default_login_id = NULL;
 char *default_password = NULL;
 char *default_prompt = FH_PROMPT_STRING;
 int setup_mode = 0;
+int yes_gnubot = 0;
 
 typedef void (*sighandler_t) (int);
 
@@ -122,6 +122,12 @@ set_setup_mode (int setup_mode_value)
   setup_mode = setup_mode_value;
 }
 
+int
+get_yes_gnubot (void)
+{
+  return yes_gnubot;
+}
+
 /* Parse a single option. */
 static error_t
 parse_opt (int key, char *arg, struct argp_state *state)
@@ -214,8 +220,8 @@ running_for_first_time (void)
 	  exit (EXIT_FAILURE);
 	}
       close (config_file_fd);
-      printf ("[%s] created\n\n", config_filename);
-      //create downloads directory
+      printf ("[%s] created\n", config_filename);
+      /* create downloads directory */
 
       if(mkdir (downloads_directory, 0755) !=0)
 	{
@@ -223,11 +229,19 @@ running_for_first_time (void)
 	  exit (EXIT_FAILURE);
 	}
     }
+  if (y_or_n_p ("\nDo you want to add \""
+		FH_ROBOT
+		"\" buddy to be in touch with the authors? [y/n]:"))
+    {
+      yes_gnubot = 1;
+    }
 
-  // this is required for delayed, higher level setup procedures
-  // that needs to be executed after guile initialization
+  /* this is required for delayed, higher level setup procedures
+     that needs to be executed after guile initialization */
   set_setup_mode (1);
 
+  printf ("\nType \"?help\" at frehoo prompt or  \"info freehoo\" for help\n\n");
+
   free (config_directory);
   free (config_filename);
   free (downloads_directory);
@@ -276,7 +290,16 @@ main (int argc, char *argv[])
   if (setrlimit (RLIMIT_CORE, &resource_limit) != 0)
     {
       perror ("setrlimit");
-      exit (EXIT_FAILURE);
+      /*
+	FIXME: Visu, Aug 23, 2004:
+	==========================
+	1. In some machines, changing ulimit values fails. For now, I
+           am just commenting out the "exit" call so that the user may
+           still be able to execute the binary though he wont be able
+           to produce core when freehoo crashes.
+	2. This needs a revisit.
+      */
+      /* exit (EXIT_FAILURE); */
     }
 
   running_for_first_time ();
