@@ -67,7 +67,7 @@
 #include "extension.h"
 
 static char *local_host = NULL;
-static int do_mail_notify = 0;
+static int do_mail_notify = 1;
 static int do_yahoo_debug = 0;
 static int ignore_system = 0;
 ///// static int do_typing_notify = 1; // commented to prevent warning
@@ -149,13 +149,16 @@ rearm (time_t * timer, int seconds)
   *timer += seconds;
 }
 
+/* FIXME: Fixed seg-fault while empty routing table. Some one needs to
+   submit this as a patch to the libyahoo2 sample-client.c source 
+   -- Anand Babu */
 static char *
 get_local_addresses ()
 {
   static char addresses[1024];
   char buff[1024];
   char gateway[16];
-  char *c;
+  char *c = NULL;
   struct hostent *hn;
   int i;
   FILE *f;
@@ -167,11 +170,18 @@ get_local_addresses ()
       c = strtok (buff, " ");
       if ((strstr (c, "default") || strstr (c, "0.0.0.0")) &&
 	  !strstr (c, "127.0.0"))
-	break;
+	{
+	  c = strtok (NULL, " ");
+	  pclose (f);
+	  break;
+	}
+      else
+	c = NULL;
     }
-  c = strtok (NULL, " ");
-  pclose (f);
 
+  if (!c || !c[0])
+    goto IP_TEST_2;
+  
   strncpy (gateway, c, 16);
 
   for (i = strlen (gateway); gateway[i] != '.'; i--)
@@ -232,7 +242,7 @@ get_time ()
 static int
 yahoo_ping_timeout_callback ()
 {
-  PRINTF_MESSAGE ("Sending a keep alive message\n");
+ /*  PRINTF_MESSAGE ("Sending a keep alive message\n"); */
   yahoo_keepalive (ylad->id);
   rearm (&pingTimer, 600);
   return 1;
@@ -1536,8 +1546,10 @@ main_loop ()
 	      break;
 	    }
 	  else
-	    break;
-	  time (&curTime);
+	    {
+	      time (&curTime);
+	      break;
+	    }
 	}
 
       if (FD_ISSET (fd_stdin, &inp))
